/**
 * <br> Sketch: bezierUtil
   <br> Author: R Eastman
   <br> Purpose: To show the use of Bezier curves and allow you pick
   <br> point locations to match an element of an image.
   <br> 
   <br> In this you click and drag the anchor and control points
   <br> to shape the curve as you want, and then hit a key to see
   <br> the point locations. 
   <br> 
   <br> If you want to copy this to your computer, you must also copy 
   <br> the image whose address is in the PDE file. You can change the
   <br> image file to your own.
*/

// Globals
// Named as g for global
//          s for start
//          e for end
//          c for control 
float gsx = 100,gsy = 100,
    gscx= 50, gscy= 50,
    gecx= 350,gecy= 350,
    gex = 300,gey = 300;
boolean start = false, end = false,
        startControl = false, endControl = false;
PImage bg;

void displayCurve(float sx, float sy,float scx,float scy,float ecx,float ecy,float ex, float ey) {      
  stroke(200,50,50);
  strokeWeight(3);
  fill(200,50,50);
  ellipse(sx,sy,5,5);
  ellipse(scx,scy,5,5);
  ellipse(ecx,ecy,5,5);
  ellipse(ex,ey,5,5);
  stroke(50,200,50);
  line(sx,sy,scx,scy);
  line(ex,ey,ecx,ecy);
  stroke(247,236,7);
  noFill();
  bezier(sx,sy,scx,scy,ecx,ecy,ex,ey);   
  }

boolean near( float x1, float y1, float x2, float y2) {
    return (abs(x1-x2) + abs(y1-y2) < 10);
}
 
 void setup () {
  size(410,399);
  bg = loadImage("pinewhite.jpg");
  smooth();
 }
 
 void draw() {
  background(bg);
  image(bg,0,0);

  if (mousePressed) {
    if (start) { gsx = mouseX; gsy = mouseY; }
    else if (startControl) { gscx = mouseX; gscy = mouseY; }
    else if (endControl) { gecx = mouseX; gecy = mouseY; }
    else if (end) { gex = mouseX; gey = mouseY; }
  }
  else { start = startControl = end = endControl = false; }
  displayCurve(gsx,gsy,gscx,gscy,gecx,gecy,gex,gey);

 }
 
 void mousePressed() {
   int x = mouseX;
   int y = mouseY;
   // near start point
   if (near(x,y,gsx,gsy))
      start = true;
   else if (near(x,y,gscx,gscy))
      startControl = true;
   else if (near(x,y,gecx,gecy))
      endControl = true;
   else if (near(x,y,gex,gey))
      end = true;
 }
 
 void keyPressed() {
   println("bezier(" + gsx + "," + gsy + "," +gscx + "," + gscy + "," + gecx + "," + gecy + "," + gex + "," + gey+ ");");
 }